@@ -18,15 +18,51 @@ __all__ = ["lamp",
 
 def lamp(waves, fwhm, fluxes):
     """
-    simple lamp function
+    Simple lamp function that creates an homogenous source with a spectra of emission lines (superposed to a very faint
+    continuum)
+
+    Parameters
+    ----------
+    waves : np.array, u.Quantity
+        a list or array of wavelengths
+    fwhm : np.array, u.Quantity
+       a list or array with the fwhm of the lines
+    fluxes : np.array, u.Quantity
+       a list or array with the fluxes of the lines
+
+    Return
+    ------
+    src : Source
+
+    Examples
+    --------
+    Create a ``Source`` lamp::
+
+        >>> import numpy as np
+        >>> import astropy.units as u
+        >>> from scopesim_templates.calibration import lamp
+        >>>
+        >>> R = 20000   # Resolution of the instrument
+        >>> waves = np.arange(1e4, 2.7e4, 100)
+        >>> fwhm = 2.6*(waves/R)*np.ones(shape=waves.shape)  # Nyquist sampled
+        >>> flux = 1e-10*np.ones(waves.shape)
+        >>>
+        >>> src = lamp(waves=waves, fwhm=fwhm, fluxes=flux)
+
     """
     params = locals()
-    warnings.warn("make sure to turn off the appropriate ScopeSim effects during the simulation")
+    print("make sure to turn off the appropriate ScopeSim effects during the simulation")
     params["object"] = "lamp"
     params["function_call"] = function_call_str(lamp, params)
 
+    if isinstance(waves, u.Quantity) is False:
+        waves = waves*u.AA
+    if isinstance(fwhm, u.Quantity) is False:
+        fwhm = fwhm*u.AA
+
+    waves = waves.to(u.AA)
     w_min, w_max = np.min(waves), np.max(waves)
-    sp = Spextrum.flat_spectrum(amplitude=40, waves=[w_min, w_max]) # A very faint spextrum to add sources
+    sp = Spextrum.flat_spectrum(amplitude=40, waves=[w_min.value, w_max.value]*u.AA)  # A very faint spextrum to add the lines
     sp = sp.add_emi_lines(center=waves, fwhm=fwhm, flux=fluxes)
     src = uniform_source(sed=sp)
     src.meta.update(params)
@@ -53,7 +89,7 @@ def flat_field(temperature=5000, amplitude=0*u.ABmag, filter_curve="V", extend=6
     amplitude: u.Quantity
         [u.Quantity] amplitude of the lamp in u.ABmag, u.mag (vega) or u. STmag
     filter_curve: str
-        any filter curve available for ``spextra``
+        any filter curve available for ``spextra``, used for scaling
 
 
     Returns
@@ -62,7 +98,7 @@ def flat_field(temperature=5000, amplitude=0*u.ABmag, filter_curve="V", extend=6
 
     """
     params = locals()
-    warnings.warn("make sure to turn off the appropriate ScopeSim effects during the simulation")
+    print("make sure to turn off the appropriate ScopeSim effects during the simulation")
     params["object"] = "flat_field"
     params["function_call"] = function_call_str(flat_field, params)
 
